var consoleRefreshTimeout = <?php echo 1000*ZM_WEB_REFRESH_MAIN ?>;
var monitors = new Array();
<?php
  global $monitors;
  foreach ( $monitors as $monitor ) {
?>
  monitors[<?php echo $monitor->Id() ?>] = {
  'Id': <?php echo $monitor->Id() ?>,
  'Name': '<?php echo $monitor->Name() ?>',
  'ViewWidth': <?php echo $monitor->ViewWidth() ?>,
  'ViewHeight':<?php echo $monitor->ViewHeight() ?>,
  'Url': '<?php echo $monitor->UrlToIndex( ZM_MIN_STREAMING_PORT ? ($monitor->Id() + ZM_MIN_STREAMING_PORT) : '') ?>',
  'Type': '<?php echo $monitor->Type() ?>',
  'Function': '<?php echo $monitor->Function() ?>',
  'Enabled': '<?php echo $monitor->Enabled() ?>',
  'DecodingEnabled': '<?php echo $monitor->DecodingEnabled() ?>'
};
<?php
  }
?>
